from django import template
from django.conf import settings
from django.template.utils import get_app_template_dirs

register = template.Library()


@register.tag
def sass(parser, token):
    nodelist = parser.parse(('endsass', ))
    parser.delete_first_token()
    return SASSNode(nodelist)


class SASSNode(template.Node):
    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        import sass as libsass
        return libsass.compile(
            string=self.nodelist.render(context),
            output_style=getattr(settings, 'DEBUG', False) and 'compressed' or 'nested',
            include_paths=[str(path) for path in get_app_template_dirs('sass')]
        )



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class Config(AppConfig):
    """
    Config for django_inline_sass application.
    """
    name = 'django_inline_sass'
    label = 'django-inline-sass'
    verbose_name = _('Django Inline SASS')

    def ready(self):
        from django_inline_sass.signals import connect_signals
        connect_signals()



from distutils.core import setup
from pkgutil import walk_packages

import django_inline_sass


def find_packages(path, prefix=""):
    yield prefix
    prefix = prefix + "."
    for _, name, ispkg in walk_packages(path, prefix):
        if ispkg:
            yield name


setup(
  name = 'django-inline-sass',
  packages = list(find_packages(django_inline_sass.__path__, django_inline_sass.__name__)),
  version = '0.1.0',
  description = 'Django Inline SASS',
  author = 'Matt Roberts',
  author_email = 'contact@maleero.com',
  url = 'https://github.com/malero/django-inline-sass',
  download_url = 'https://github.com/malero/django-inline-sass/archive/v0.1.0.tar.gz',
  keywords = ['django', 'sass', 'seo'],
  classifiers = [],
  install_requires=['libsass==0.21.0',],
)
